#
#  This is the configuration file that allows to configure values that are
# required to access various S3 stores.
#
# If you want to add a S3 store that is not available as an entry, yet:
#   - create a new (unique!) key within the TYPES dict
#   - add a dict as value to the key, holding the same keys (all of them!)
#     as there are in the existing ones
#   - enter a default endpoint, and
#   - a region (if the new S3 store supports regions)
#   - if the S3 store has regions, add the new key to the REGIONREQUIRED list
#

# the TYPES dict describes the parameters that are used in .hs3sh.conf:
TYPES = {'aws': {'comment': '',
                 'endpoint': 's3.amazonaws.com',
                 'region': 'us-east-1',
                 'https': True,
                 'port': 443,
                 'aws_access_key_id': '',
                 'aws_secret_access_key': ''
                 },
         'cloudian': {'comment': '',
                      'endpoint': 'cloudian.your.domain',
                      'region': 's3-region',
                      'https': True,
                      'port': 443,
                      'aws_access_key_id': '',
                      'aws_secret_access_key': ''
                      },
         'ecs': {'comment': '',
                 'endpoint': 'namespace.ecs.your.domain',
                 'region': '',
                 'https': True,
                 'port': 9021,
                 'aws_access_key_id': '',
                 'aws_secret_access_key': ''
                 },
         'hs3': {'comment': '',
                 'endpoint': 'tenant.hcp.your.domain',
                 'region': '',
                 'https': True,
                 'port': 443,
                 'aws_access_key_id': '',
                 'aws_secret_access_key': ''
                 },
         'compatible': {'comment': '',
                        'endpoint': 'whatever.your.domain',
                        'region': '',
                        'https': True,
                        'port': 443,
                        'aws_access_key_id': '',
                        'aws_secret_access_key': ''
                        },
         }

# these are the S3 store types that require a region to be set:
REGIONREQUIRED = ['aws', 'cloudian']

##### NO CHANGES BELOW THIS LINE, PLEASE #####
# these are boolean tags
BOOLTAGS = ['https']
# these are integer tags
INTTAGS = ['port']
# these are the keys that _need_ to have entries in .hs3sh.conf:
REQUIRED = ['endpoint', 'https', 'port',
            'aws_access_key_id', 'aws_secret_access_key']
# these are the keys that are optional:
OPTIONAL = ['comment', 'region']


# -*- coding: utf-8 -*-
# The MIT License (MIT)
#
# Copyright (c) 2016-2018 Thorsten Simons (sw@snomis.de)
#
# Permission is hereby granted, free of charge, to any person obtaining a
# copy of this software and associated documentation files (the "Software"),
# to deal in the Sos of the Software, and to permit persons to whom the
# Software is furnished to do so, subject to the following conditions:
#
# The above copyrighftware without restriction, including without limitation
# the rights to use, copy, modify, merge, publish, distribute, sublicense,
# and/or sell copiet notice and this permission notice shall be included in
# all copies or substantial portions of the Software.
#
# THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
# IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
# FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
# THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
# LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
# FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER
# DEALINGS IN THE SOFTWARE.

import sys
from setuptools import setup, find_packages
from codecs import open  # To use a consistent encoding
from os import path
# this is to be able to get the version without importing *hcpcbc*,
# which would cause *pip install* to fail.
sys.path.insert(0, path.abspath('hs3'))
from init import Gvars

here = path.abspath(path.dirname(__file__))

# Get the long description from the relevant file
with open(path.join(here, 'DESCRIPTION.rst'), encoding='utf-8') as f:
    long_description = f.read()

setup(
    name='hs3sh',
    # Versions should comply with PEP440. For a discussion on single-sourcing
    # the version across setup.py and the project code, see
    # http://packaging.python.org/en/latest/tutorial.html#version

    version=str(Gvars.s_version),
    description=Gvars.Description,
    long_description=long_description,

    # The project's main homepage.
    url='https://hs3sh.readthedocs.org',

    # Author details
    author=Gvars.Author,
    author_email=Gvars.AuthorMail,

    # Choose your license
    license='MIT',

    # See https://pypi.python.org/pypi?%3Aaction=list_classifiers
    classifiers=[
        # How mature is this project? Common values are
        # 3 - Alpha
        # 4 - Beta
        # 5 - Production/Stable
        'Development Status :: 5 - Production/Stable',

        # Indicate who your project is intended for
        'Intended Audience :: System Administrators',
        'Topic :: System :: Archiving',

        # Pick your license as you wish (should match "license" above)
        'License :: OSI Approved :: MIT License',

        # Specify the Python versions you support here. In particular, ensure
        # that you indicate whether you support Python 2, Python 3 or both.
        'Programming Language :: Python :: 3',

        # more...
        'Operating System :: OS Independent',
        'Natural Language :: English',
    ],

    # What does your project relate to?
    keywords='Amazon S3 compatible HCP HS3 Hitachi Content Platform',

    # You can just specify the packages manually here if your project is
    # simple. Or you can use find_packages().
    packages=find_packages(exclude=[]),

    # List run-time dependencies here. These will be installed by pip when your
    # project is installed. For an analysis of "install_requires" vs pip's
    # requirements files see:
    # https://packaging.python.org/en/latest/technical.html#install-requires-vs-requirements-files
    install_requires=['boto3>=1.2.6'],

    # List additional groups of dependencies here (e.g. development dependencies).
    # You can install these using the following syntax, for example:
    # $ pip install -e .[dev,test]
    # extras_require = {'dev': ['Sphinx'],
    #                   },

    # If there are data files included in your packages that need to be
    # installed, specify them here. If using Python 2.6 or less, then these
    # have to be included in MANIFEST.in as well.
    # package_data={
    #               'sample': ['package_data.dat'],
    #               },

    # Although 'package_data' is the preferred approach, in some case you may
    # need to place data files outside of your packages.
    # see http://docs.python.org/3.4/distutils/setupscript.html#installing-additional-files
    # In this case, 'data_file' will be installed into '<sys.prefix>/my_data'
    # data_files=[('my_data', ['data/data_file'])],

    # To provide executable scripts, use entry points in preference to the
    # "scripts" keyword. Entry points provide cross-platform support and allow
    # pip to create the appropriate form of executable for the Target platform.
    entry_points={'console_scripts': ['hs3sh = hs3sh.__main__:main']}
)
